@@ -1,12 +1,12 @@
 #!/usr/bin/perl
-#VERSION,1.10
+#VERSION,1.12
 use Getopt::Long;
 Getopt::Long::Configure('no_ignore_case');
 
 # The LW require has been moved down about 40 lines...
 
 #######################################################################
-# last update: 09.13.2003
+# last update: 10.27.2003
 # --------------------------------------------------------------------#
 #                               Nikto                                 #
 # --------------------------------------------------------------------#
@@ -37,10 +37,10 @@ Getopt::Long::Configure('no_ignore_case');
 # global var/definitions
 use vars qw/@OPTS %CLI %VARIABLES $CONTENT $ITEMCOUNT @COOKIES %FILES $CURRENT_HOST_ID $CURRENT_PORT/;
 use vars qw/%CONFIG %NIKTO %OUTPUT %METHD %RESPS %INFOS %SERVER %request %result %JAR %DATAS %COUNTERS/;
-use vars qw/%UPDATES $DIV $VULS $OKTRAP $HOST %TARGETS @DBFILE @SERVERFILE @BUILDITEMS $PROXYCHECKED/;
+use vars qw/%CFG %UPDATES $DIV $VULS $OKTRAP $HOST %TARGETS @DBFILE @SERVERFILE @BUILDITEMS $PROXYCHECKED/;
 
 # setup
-$NIKTO{version}="1.31";
+$NIKTO{version}="1.32";
 $NIKTO{name}="Nikto";
 $CFG{configfile}="config.txt";
 $DIV = "-" x 75;
@@ -53,6 +53,12 @@ require "$NIKTO{plugindir}/LW.pm";
 general_config();
 
 LW::http_init_request(\%request);
+$request{'whisker'}{'lowercase_incoming_headers'} = 1;
+$request{'whisker'}->{'lowercase_incoming_headers'}=1;
+$request{'whisker'}->{'timeout'}=$CLI{timeout} || 10;
+$request{'whisker'}->{'anti_ids'}=$CLI{evasion};
+$request{'User-Agent'} = $NIKTO{useragent};
+$request{'Host'} = $CLI{vhost} unless $CLI{vhost} eq "";
 proxy_setup();
 
 open_output();
@@ -69,26 +75,20 @@ foreach $CURRENT_HOST_ID (sort { $a<=>$b } keys %TARGETS)
   $COUNTERS{hosts_completed}++;
   if (($CLI{findonly}) && ($COUNTERS{hosts_completed} % 10) eq 0) { nprint("($COUNTERS{hosts_completed} of $COUNTERS{hosts_total})"); }
   host_config();
+  $request{'whisker'}->{'host'} = $TARGETS{$CURRENT_HOST_ID}{hostname} || $TARGETS{$CURRENT_HOST_ID}{ip};
 
   foreach $CURRENT_PORT ( keys %{$TARGETS{$CURRENT_HOST_ID}{ports}} )
    {
     if ($CURRENT_PORT eq "") { next; }
-    $request{'whisker'}->{'host'}=$TARGETS{$CURRENT_HOST_ID}{ip};
     $request{'whisker'}->{'port'}=$CURRENT_PORT;
     $request{'whisker'}->{'ssl'}=$TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{ssl};
-    $request{'whisker'}->{'lowercase_incoming_headers'}=1;
     $request{'whisker'}->{'http_ver'}=$CONFIG{DEFAULTHTTPVER};
-    $request{'whisker'}->{'timeout'}=$CLI{timeout} || 10;
-    $request{'User-Agent'} = $NIKTO{useragent};
-    $request{'whisker'}->{'anti_ids'}=$CLI{evasion};
-    $request{'Host'}=$CLI{vhost} || $TARGETS{$CURRENT_HOST_ID}{hostname} || $TARGETS{$CURRENT_HOST_ID}{ip};
     if ($CONFIG{'STATIC-COOKIE'} ne "") { $request{'Cookie'} = $CONFIG{'STATIC-COOKIE'}; }
-    $VULS=0;
 
-    proxy_check();
     get_banner();
 
-    if ($CLI{findonly}) { 
+    if ($CLI{findonly}) 
+    { 
      my $protocol="http";
      if ($TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{banner} eq "") { $TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{banner}="(no identification possible)"; }
      if ($TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{ssl}) { $protocol .= "s"; }
@@ -96,6 +96,7 @@ foreach $CURRENT_HOST_ID (sort { $a<=>$b } keys %TARGETS)
      next;
     }
 
+    $VULS=0;
     dump_target_info();
     check_responses();
     check_cgi();
